Certificates | OiRA
Description: Depending the approach taken by the respective OiRA tool developer/partner, it might be possible to obtain a certificate for your risk assessment. For details about the advantages of such certificates, please contact your national OiRA partner.

Topics

# Certificates

Depending the approach taken by the respective OiRA tool developer/partner, it might be possible to obtain a certificate for your risk assessment. For details about the advantages of such certificates, please contact your national OiRA partner.

How to obtain a certificate

## Do a full risk assessment

As you work through your risk assessment, OiRA will record your progess. Once you have assessed a small percentage of risks, the tools informs you about the possibility to get a certificate once you have finalised the full risk assessment. Each national OiRA partner/tool developer sets this threshold on how a “full” risk assessment is defined. The certificate is available through the “Status” button in the left hand menu.

## View and publish your certificate

When you click the button “View certificate”, you will be asked to enter the name of your company that should appear on the certificate. Depending on national settings, you might be asked to enter further data to make sure the certificate gives all the information you need to provide.

If you tick the check-box labelled “Make public”, a unique link (URL) to your certificate will be shown to you. Copy this link and share it with whom it may concern as proof that you have conducted your risk assessment.

Note: Only the data shown on this page will be made public. This link is not available through the menu of any website etc. It is specific for you. However, theoretically anyone who browses the internet could see the certificate you have launched!

The certificate only shows that you have answered a certain percentage of risks in the risk assessment tool but does not give any other information. The specific answers to the risk assessment given when completing the OiRA tool can only be viewed by you and nobody else!

Scroll to top
Back

## 5-certificates.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search